@@ -1,26 +1,22 @@
 import pytest
 
-from pytest_snapshot.plugin import text_type
 from tests.utils import assert_pytest_passes
 
 
 @pytest.fixture
 def basic_case_dir(testdir):
     case_dir = testdir.mkdir('case_dir')
-    case_dir.join('snapshot1.txt').write_text(u'the value of snapshot1.txt', 'ascii')
+    case_dir.join('snapshot1.txt').write_text('the valuÉ of snapshot1.txt', 'utf-8')
     return case_dir
 
 
 def test_assert_match_with_external_snapshot_path(testdir, basic_case_dir):
     testdir.makepyfile("""
-        try:
-            from pathlib import Path
-        except ImportError:
-            from pathlib2 import Path
+        from pathlib import Path
 
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the value of snapshot1.txt', Path('not_case_dir/snapshot1.txt').absolute())
+            snapshot.assert_match('the value of snapshot1.txt', Path('not_case_dir/snapshot1.txt').absolute())
     """)
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
@@ -30,20 +26,29 @@ def test_assert_match_with_external_snapshot_path(testdir, basic_case_dir):
     assert result.ret == 1
 
 
-def test_assert_match_success(testdir, basic_case_dir):
+def test_assert_match_success_string(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the value of snapshot1.txt', 'snapshot1.txt')
+            snapshot.assert_match('the valuÉ of snapshot1.txt', 'snapshot1.txt')
     """)
     assert_pytest_passes(testdir)
 
 
-def test_assert_match_failure(testdir, basic_case_dir):
+def test_assert_match_success_bytes(testdir, basic_case_dir):
+    testdir.makepyfile(r"""
+        def test_sth(snapshot):
+            snapshot.snapshot_dir = 'case_dir'
+            snapshot.assert_match(b'the valu\xc3\x89 of snapshot1.txt', 'snapshot1.txt')
+    """)
+    assert_pytest_passes(testdir)
+
+
+def test_assert_match_failure_string(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the INCORRECT value of snapshot1.txt', 'snapshot1.txt')
+            snapshot.assert_match('the INCORRECT value of snapshot1.txt', 'snapshot1.txt')
     """)
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
@@ -51,9 +56,30 @@ def test_assert_match_failure(testdir, basic_case_dir):
         ">* raise AssertionError(snapshot_diff_msg)",
         'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
         "E* assert * == *",
-        "E* - the value of snapshot1.txt",
+        "E* - the valuÉ of snapshot1.txt",
+        "E* ?         ^",
         "E* + the INCORRECT value of snapshot1.txt",
-        "E* ?    ++++++++++",
+        "E* ?    ++++++++++     ^",
+    ])
+    assert result.ret == 1
+
+
+def test_assert_match_failure_bytes(testdir, basic_case_dir):
+    testdir.makepyfile("""
+        def test_sth(snapshot):
+            snapshot.snapshot_dir = 'case_dir'
+            snapshot.assert_match(b'the INCORRECT value of snapshot1.txt', 'snapshot1.txt')
+    """)
+    result = testdir.runpytest('-v')
+    result.stdout.fnmatch_lines([
+        r'*::test_sth FAILED*',
+        r">* raise AssertionError(snapshot_diff_msg)",
+        r'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
+        r"E* assert * == *",
+        r"E* At index 4 diff: * != *",
+        r"E* Full diff:",
+        r"E* - b'the valu\xc3\x89 of snapshot1.txt'",
+        r"E* + b'the INCORRECT value of snapshot1.txt'",
     ])
     assert result.ret == 1
 
@@ -62,12 +88,12 @@ def test_assert_match_invalid_type(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(b'incorrect typed obj', 'snapshot1.txt')
+            snapshot.assert_match(123, 'snapshot1.txt')
     """)
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        'E* TypeError: value must be {}'.format(text_type.__name__),
+        'E* TypeError: value must be str or bytes',
     ])
     assert result.ret == 1
 
@@ -76,7 +102,7 @@ def test_assert_match_missing_snapshot(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'something', 'snapshot_that_doesnt_exist.txt')
+            snapshot.assert_match('something', 'snapshot_that_doesnt_exist.txt')
     """)
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
@@ -91,7 +117,7 @@ def test_assert_match_update_existing_snapshot_no_change(testdir, basic_case_dir
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the value of snapshot1.txt', 'snapshot1.txt')
+            snapshot.assert_match('the valuÉ of snapshot1.txt', 'snapshot1.txt')
     """)
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
@@ -127,14 +153,11 @@ def test_assert_match_update_existing_snapshot(testdir, basic_case_dir, case_dir
     Also tests that `Snapshot` supports absolute/relative str/Path snapshot directories and snapshot paths.
     """
     testdir.makepyfile("""
-        try:
-            from pathlib import Path
-        except ImportError:
-            from pathlib2 import Path
+        from pathlib import Path
 
         def test_sth(snapshot):
             snapshot.snapshot_dir = {case_dir_repr}
-            snapshot.assert_match(u'the NEW value of snapshot1.txt', {snapshot_name_repr})
+            snapshot.assert_match('the NEW value of snapshot1.txt', {snapshot_name_repr})
     """.format(case_dir_repr=case_dir_repr, snapshot_name_repr=snapshot_name_repr))
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
@@ -155,14 +178,11 @@ def test_assert_match_update_existing_snapshot_and_exception_in_test(testdir, ba
     In this case, both the snapshot update error and the test function error are printed out.
     """
     testdir.makepyfile("""
-        try:
-            from pathlib import Path
-        except ImportError:
-            from pathlib2 import Path
+        from pathlib import Path
 
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the NEW value of snapshot1.txt', 'snapshot1.txt')
+            snapshot.assert_match('the NEW value of snapshot1.txt', 'snapshot1.txt')
             assert False
     """)
     result = testdir.runpytest('-v', '--snapshot-update')
@@ -181,7 +201,7 @@ def test_assert_match_create_new_snapshot(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'the NEW value of new_snapshot1.txt', 'sub_dir/new_snapshot1.txt')
+            snapshot.assert_match('the NEW value of new_snapshot1.txt', 'sub_dir/new_snapshot1.txt')
     """)
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
@@ -199,7 +219,7 @@ def test_assert_match_create_new_snapshot(testdir, basic_case_dir):
 def test_assert_match_create_new_snapshot_in_default_dir(testdir):
     testdir.makepyfile("""
         def test_sth(snapshot):
-            snapshot.assert_match(u'the value of new_snapshot1.txt', 'sub_dir/new_snapshot1.txt')
+            snapshot.assert_match('the value of new_snapshot1.txt', 'sub_dir/new_snapshot1.txt')
     """)
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
@@ -212,7 +232,7 @@ def test_assert_match_create_new_snapshot_in_default_dir(testdir):
     assert result.ret == 1
     assert testdir.tmpdir.join(
         'snapshots/test_assert_match_create_new_snapshot_in_default_dir/test_sth/sub_dir/new_snapshot1.txt'
-    ).read_text('utf-8') == u'the value of new_snapshot1.txt'
+    ).read_text('utf-8') == 'the value of new_snapshot1.txt'
 
     assert_pytest_passes(testdir)  # assert that snapshot update worked
 
@@ -222,7 +242,7 @@ def test_assert_match_existing_snapshot_is_not_file(testdir, basic_case_dir):
     testdir.makepyfile("""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
-            snapshot.assert_match(u'something', 'directory1')
+            snapshot.assert_match('something', 'directory1')
     """)
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
